@@ -172,7 +172,7 @@ static void addressbook_edit_address_create(gboolean *cancelled)
 	debug_print("Creating edit_address window...\n");
 
 	window = gtk_window_new(GTK_WINDOW_DIALOG);
-	gtk_widget_set_usize(window, 400, -1);
+	gtk_widget_set_size_request(window, 400, -1);
 	/* gtk_container_set_border_width(GTK_CONTAINER(window), 8); */
 	gtk_window_set_title(GTK_WINDOW(window), _("Edit address"));
 	gtk_window_set_position(GTK_WINDOW(window), GTK_WIN_POS_CENTER);
