@@ -116,7 +116,8 @@ static void combo_button_size_request(GtkWidget *widget,
 	ComboButton *combo = (ComboButton *)data;
 
 	if (combo->arrow->allocation.height != requisition->height)
-		gtk_widget_set_usize(combo->arrow, -1, requisition->height);
+		gtk_widget_set_size_request(combo->arrow,
+					    -1, requisition->height);
 }
 
 static void combo_button_enter(GtkWidget *widget, gpointer data)
@@ -190,20 +191,20 @@ ComboButton *gtkut_combo_button_create(GtkWidget *button,
 					&combo->factory, data);
 	combo->data = data;
 
-	gtk_signal_connect(GTK_OBJECT(combo->button), "size_request",
-			   GTK_SIGNAL_FUNC(combo_button_size_request), combo);
-	gtk_signal_connect(GTK_OBJECT(combo->button), "enter",
-			   GTK_SIGNAL_FUNC(combo_button_enter), combo);
-	gtk_signal_connect(GTK_OBJECT(combo->button), "leave",
-			   GTK_SIGNAL_FUNC(combo_button_leave), combo);
-	gtk_signal_connect(GTK_OBJECT(combo->arrow), "enter",
-			   GTK_SIGNAL_FUNC(combo_button_enter), combo);
-	gtk_signal_connect(GTK_OBJECT(combo->arrow), "leave",
-			   GTK_SIGNAL_FUNC(combo_button_leave), combo);
-	gtk_signal_connect(GTK_OBJECT(combo->arrow), "button_press_event",
-			   GTK_SIGNAL_FUNC(combo_button_arrow_pressed), combo);
-	gtk_signal_connect(GTK_OBJECT(combo->arrow), "destroy",
-			   GTK_SIGNAL_FUNC(combo_button_destroy), combo);
+	g_signal_connect(G_OBJECT(combo->button), "size_request",
+			 G_CALLBACK(combo_button_size_request), combo);
+	g_signal_connect(G_OBJECT(combo->button), "enter",
+			 G_CALLBACK(combo_button_enter), combo);
+	g_signal_connect(G_OBJECT(combo->button), "leave",
+			 G_CALLBACK(combo_button_leave), combo);
+	g_signal_connect(G_OBJECT(combo->arrow), "enter",
+			 G_CALLBACK(combo_button_enter), combo);
+	g_signal_connect(G_OBJECT(combo->arrow), "leave",
+			 G_CALLBACK(combo_button_leave), combo);
+	g_signal_connect(G_OBJECT(combo->arrow), "button_press_event",
+			 G_CALLBACK(combo_button_arrow_pressed), combo);
+	g_signal_connect(G_OBJECT(combo->arrow), "destroy",
+			 G_CALLBACK(combo_button_destroy), combo);
 
 	return combo;
 }
@@ -389,6 +390,22 @@ gchar *gtkut_editable_get_selection(GtkEditable *editable)
 		return NULL;
 }
 
+void gtkut_editable_disable_im(GtkEditable *editable)
+{
+	g_return_if_fail(editable != NULL);
+
+#if USE_XIM
+	if (editable->ic) {
+		gdk_ic_destroy(editable->ic);
+		editable->ic = NULL;
+	}
+	if (editable->ic_attr) {
+		gdk_ic_attr_destroy(editable->ic_attr);
+		editable->ic_attr = NULL;
+	}
+#endif
+}
+
 /*
  * Walk through the widget tree and disclaim the selection from all currently
  * realized GtkEditable widgets.
