@@ -43,7 +43,6 @@
 #include "procmsg.h"
 #include "procheader.h"
 #include "folder.h"
-#include "statusbar.h"
 #include "prefs_account.h"
 #include "codeconv.h"
 #include "md5.h"
@@ -439,18 +438,14 @@ static IMAPSession *imap_session_get(Folder *folder)
 
 	if (!rfolder->session) {
 		rfolder->session = imap_session_new(folder->account);
-		if (rfolder->session) {
+		if (rfolder->session)
 			imap_parse_namespace(IMAP_SESSION(rfolder->session),
 					     IMAP_FOLDER(folder));
-			rfolder->session->last_access_time = time(NULL);
-		}
-		statusbar_pop_all();
 		return IMAP_SESSION(rfolder->session);
 	}
 
-	if (time(NULL) - rfolder->session->last_access_time < SESSION_TIMEOUT) {
-		rfolder->session->last_access_time = time(NULL);
-		statusbar_pop_all();
+	if (time(NULL) - rfolder->session->last_access_time <
+		SESSION_TIMEOUT_INTERVAL) {
 		return IMAP_SESSION(rfolder->session);
 	}
 
@@ -465,9 +460,6 @@ static IMAPSession *imap_session_get(Folder *folder)
 					     IMAP_FOLDER(folder));
 	}
 
-	if (rfolder->session)
-		rfolder->session->last_access_time = time(NULL);
-	statusbar_pop_all();
 	return IMAP_SESSION(rfolder->session);
 }
 
@@ -802,7 +794,6 @@ static GSList *imap_get_msg_list(Folder *folder, FolderItem *item,
 		mlist = procmsg_read_cache(item, FALSE);
 		item->last_num = procmsg_get_last_num_in_msg_list(mlist);
 		procmsg_set_flags(mlist, item);
-		statusbar_pop_all();
 		return mlist;
 	}
 
@@ -812,7 +803,6 @@ static GSList *imap_get_msg_list(Folder *folder, FolderItem *item,
 
 	if (exists == 0) {
 		imap_delete_all_cached_messages(item);
-		statusbar_pop_all();
 		return NULL;
 	}
 
@@ -963,7 +953,6 @@ static GSList *imap_get_msg_list(Folder *folder, FolderItem *item,
 	item->last_num = last_uid;
 
 catch:
-	statusbar_pop_all();
 	return mlist;
 }
 
@@ -997,7 +986,6 @@ static gchar *imap_fetch_msg(Folder *folder, FolderItem *item, gint uid)
 
 	ok = imap_select(session, IMAP_FOLDER(folder), item->path,
 			 NULL, NULL, NULL, NULL);
-	statusbar_pop_all();
 	if (ok != IMAP_SUCCESS) {
 		g_warning("can't select mailbox %s\n", item->path);
 		g_free(filename);
@@ -1007,8 +995,6 @@ static gchar *imap_fetch_msg(Folder *folder, FolderItem *item, gint uid)
 	debug_print("getting message %d...\n", uid);
 	ok = imap_cmd_fetch(session, (guint32)uid, filename);
 
-	statusbar_pop_all();
-
 	if (ok != IMAP_SUCCESS) {
 		g_warning("can't fetch message %d\n", uid);
 		g_free(filename);
@@ -1077,7 +1063,6 @@ static gint imap_add_msgs(Folder *folder, FolderItem *dest, GSList *file_list,
 
 	ok = imap_status(session, IMAP_FOLDER(folder), dest->path,
 			 &messages, &recent, &uid_next, &uid_validity, &unseen);
-	statusbar_pop_all();
 	if (ok != IMAP_SUCCESS) {
 		g_warning("can't append messages\n");
 		return -1;
@@ -1176,7 +1161,6 @@ static gint imap_do_copy_msgs(Folder *folder, FolderItem *dest, GSList *msglist,
 
 	ok = imap_select(session, IMAP_FOLDER(folder), src->path,
 			 NULL, NULL, NULL, NULL);
-	statusbar_pop_all();
 	if (ok != IMAP_SUCCESS)
 		return ok;
 
@@ -1234,7 +1218,6 @@ static gint imap_do_copy_msgs(Folder *folder, FolderItem *dest, GSList *msglist,
 	}
 
 	g_free(destdir);
-	statusbar_pop_all();
 
 	if (ok == IMAP_SUCCESS)
 		return 0;
@@ -1384,7 +1367,6 @@ static gint imap_remove_msgs(Folder *folder, FolderItem *item, GSList *msglist)
 
 	ok = imap_select(session, IMAP_FOLDER(folder), item->path,
 			 NULL, NULL, NULL, NULL);
-	statusbar_pop_all();
 	if (ok != IMAP_SUCCESS)
 		return ok;
 
@@ -1428,20 +1410,17 @@ static gint imap_remove_all_msg(Folder *folder, FolderItem *item)
 
 	ok = imap_select(session, IMAP_FOLDER(folder), item->path,
 			 NULL, NULL, NULL, NULL);
-	statusbar_pop_all();
 	if (ok != IMAP_SUCCESS)
 		return ok;
 
 	imap_cmd_gen_send(session, "STORE 1:* +FLAGS.SILENT (\\Deleted)");
 	ok = imap_cmd_ok(session, NULL);
-	statusbar_pop_all();
 	if (ok != IMAP_SUCCESS) {
 		log_warning(_("can't set deleted flags: 1:*\n"));
 		return ok;
 	}
 
 	ok = imap_cmd_expunge(session);
-	statusbar_pop_all();
 	if (ok != IMAP_SUCCESS) {
 		log_warning(_("can't expunge\n"));
 		return ok;
@@ -1505,7 +1484,6 @@ static gint imap_scan_folder(Folder *folder, FolderItem *item)
 
 	ok = imap_status(session, IMAP_FOLDER(folder), item->path,
 			 &messages, &recent, &uid_next, &uid_validity, &unseen);
-	statusbar_pop_all();
 	if (ok != IMAP_SUCCESS) return -1;
 
 	item->new = unseen > 0 ? recent : 0;
@@ -1802,7 +1780,6 @@ static GSList *imap_parse_list(IMAPSession *session, const gchar *real_path,
 	}
 
 	g_string_free(str, TRUE);
-	statusbar_pop_all();
 
 	return item_list;
 }
@@ -1875,7 +1852,7 @@ static FolderItem *imap_create_special_folder(Folder *folder,
 }
 
 static FolderItem *imap_create_folder(Folder *folder, FolderItem *parent,
-			       const gchar *name)
+				      const gchar *name)
 {
 	gchar *dirpath, *imap_path;
 	IMAPSession *session;
@@ -1925,7 +1902,6 @@ static FolderItem *imap_create_folder(Folder *folder, FolderItem *parent,
 
 		argbuf = g_ptr_array_new();
 		ok = imap_cmd_list(session, NULL, imap_path, argbuf);
-		statusbar_pop_all();
 		if (ok != IMAP_SUCCESS) {
 			log_warning(_("can't create mailbox: LIST failed\n"));
 			g_free(imap_path);
@@ -1946,7 +1922,6 @@ static FolderItem *imap_create_folder(Folder *folder, FolderItem *parent,
 
 		if (!exist) {
 			ok = imap_cmd_create(session, imap_path);
-			statusbar_pop_all();
 			if (ok != IMAP_SUCCESS) {
 				log_warning(_("can't create mailbox\n"));
 				g_free(imap_path);
@@ -1999,7 +1974,6 @@ static gint imap_rename_folder(Folder *folder, FolderItem *item,
 	session->mbox = NULL;
 	ok = imap_cmd_examine(session, "INBOX",
 			      &exists, &recent, &unseen, &uid_validity);
-	statusbar_pop_all();
 	if (ok != IMAP_SUCCESS) {
 		g_free(real_oldpath);
 		return -1;
@@ -2017,7 +1991,6 @@ static gint imap_rename_folder(Folder *folder, FolderItem *item,
 	imap_path_separator_subst(real_newpath, separator);
 
 	ok = imap_cmd_rename(session, real_oldpath, real_newpath);
-	statusbar_pop_all();
 	if (ok != IMAP_SUCCESS) {
 		log_warning(_("can't rename mailbox: %s to %s\n"),
 			    real_oldpath, real_newpath);
@@ -2074,14 +2047,12 @@ static gint imap_remove_folder(Folder *folder, FolderItem *item)
 
 	ok = imap_cmd_examine(session, "INBOX",
 			      &exists, &recent, &unseen, &uid_validity);
-	statusbar_pop_all();
 	if (ok != IMAP_SUCCESS) {
 		g_free(path);
 		return -1;
 	}
 
 	ok = imap_cmd_delete(session, path);
-	statusbar_pop_all();
 	if (ok != IMAP_SUCCESS) {
 		log_warning(_("can't delete mailbox\n"));
 		g_free(path);
@@ -2181,6 +2152,8 @@ static GSList *imap_get_uncached_messages(IMAPSession *session,
 
 	g_string_free(str, TRUE);
 
+	session_set_access_time(SESSION(session));
+
 	return newlist;
 }
 
@@ -2746,7 +2719,6 @@ static gint imap_msg_list_change_perm_flags(GSList *msglist, MsgPermFlags flags,
 
 	ok = imap_select(session, IMAP_FOLDER(folder), msginfo->folder->path,
 			 NULL, NULL, NULL, NULL);
-	statusbar_pop_all();
 	if (ok != IMAP_SUCCESS)
 		return ok;
 
@@ -3570,6 +3542,8 @@ static gint imap_cmd_gen_recv(IMAPSession *session, gchar **ret)
 
 	log_print("IMAP4< %s\n", *ret);
 
+	session_set_access_time(SESSION(session));
+
 	return IMAP_SUCCESS;
 }
 
@@ -3698,7 +3672,7 @@ static gchar *imap_modified_utf7_to_utf8(const gchar *mutf7_str)
 	if (!iconv_ok) return g_strdup(mutf7_str);
 
 	if (cd == (iconv_t)-1) {
-		cd = iconv_open(conv_get_current_charset_str(), CS_UTF_8);
+		cd = iconv_open(CS_UTF_8, "UTF-7");
 		if (cd == (iconv_t)-1) {
 			g_warning(_("iconv cannot convert UTF-7 to UTF-8\n"));
 			iconv_ok = FALSE;
@@ -3819,11 +3793,7 @@ static gchar *imap_utf8_to_modified_utf7(const gchar *from)
 			/* unprintable char: convert to UTF-7 */
 			p = from_tmp;
 			while (!IS_PRINT(*(guchar *)p) && conv_len < from_len) {
-				mb_len = mblen(p, MB_LEN_MAX);
-				if (mb_len <= 0) {
-					g_warning("wrong multibyte sequence\n");
-					return g_strdup(from);
-				}
+				mb_len = g_utf8_skip[*(guchar *)p];
 				conv_len += mb_len;
 				p += mb_len;
 			}
