@@ -1,6 +1,6 @@
 /*
  * Sylpheed -- a GTK+ based, lightweight, and fast e-mail client
- * Copyright (C) 1999-2003 Hiroyuki Yamamoto
+ * Copyright (C) 1999-2004 Hiroyuki Yamamoto
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -182,6 +182,8 @@ static GtkItemFactoryEntry msgview_entries[] =
 	 CODESET_ACTION(C_ISO_8859_5)},
 	{N_("/_View/_Code set/Cyrillic (KOI8-_R)"),
 	 CODESET_ACTION(C_KOI8_R)},
+	{N_("/_View/_Code set/Cyrillic (KOI8-U)"),
+	 CODESET_ACTION(C_KOI8_U)},
 	{N_("/_View/_Code set/Cyrillic (Windows-1251)"),
 	 CODESET_ACTION(C_CP1251)},
 	CODESET_SEPARATOR,
@@ -273,7 +275,6 @@ MessageView *messageview_create(void)
 	GtkWidget *vbox;
 	HeaderView *headerview;
 	TextView *textview;
-	ImageView *imageview;
 	MimeView *mimeview;
 
 	debug_print(_("Creating message view...\n"));
@@ -286,13 +287,11 @@ MessageView *messageview_create(void)
 	textview = textview_create();
 	textview->messageview = messageview;
 
-	imageview = imageview_create();
-	imageview->messageview = messageview;
-
 	mimeview = mimeview_create();
 	mimeview->textview = textview_create();
 	mimeview->textview->messageview = messageview;
-	mimeview->imageview = imageview;
+	mimeview->imageview = imageview_create();
+	mimeview->imageview->messageview = messageview;
 	mimeview->messageview = messageview;
 
 	vbox = gtk_vbox_new(FALSE, 0);
@@ -304,17 +303,20 @@ MessageView *messageview_create(void)
 
 	/* to remove without destroyed */
 	gtk_widget_ref(GTK_WIDGET_PTR(textview));
-	gtk_widget_ref(GTK_WIDGET_PTR(imageview));
 	gtk_widget_ref(GTK_WIDGET_PTR(mimeview));
 	gtk_widget_ref(GTK_WIDGET_PTR(mimeview->textview));
+	gtk_widget_ref(GTK_WIDGET_PTR(mimeview->imageview));
 
-	messageview->vbox       = vbox;
-	messageview->new_window = FALSE;
-	messageview->window     = NULL;
-	messageview->headerview = headerview;
-	messageview->textview   = textview;
-	messageview->imageview  = imageview;
-	messageview->mimeview   = mimeview;
+	messageview->vbox        = vbox;
+	messageview->new_window  = FALSE;
+	messageview->window      = NULL;
+	messageview->window_vbox = NULL;
+	messageview->headerview  = headerview;
+	messageview->textview    = textview;
+	messageview->mimeview    = mimeview;
+
+	messageview->statusbar     = NULL;
+	messageview->statusbar_cid = 0;
 
 	return messageview;
 }
@@ -323,8 +325,11 @@ MessageView *messageview_create_with_new_window(void)
 {
 	MessageView *msgview;
 	GtkWidget *window;
+	GtkWidget *window_vbox;
+	GtkWidget *body_vbox;
 	GtkWidget *menubar;
 	GtkItemFactory *ifactory;
+	GtkWidget *statusbar;
 	guint n_menu_entries;
 
 	window = gtk_window_new(GTK_WINDOW_TOPLEVEL);
@@ -336,6 +341,9 @@ MessageView *messageview_create_with_new_window(void)
 
 	msgview = messageview_create();
   
+	window_vbox = gtk_vbox_new(FALSE, 0);
+	gtk_container_add(GTK_CONTAINER(window), window_vbox);
+
 	g_signal_connect(G_OBJECT(window), "size_allocate",
 			 G_CALLBACK(messageview_size_allocate_cb),
 			 msgview);
@@ -352,15 +360,28 @@ MessageView *messageview_create_with_new_window(void)
 #if 0
 	menu_factory_copy_rc("<Main>", "<MessageView>");
 #endif
-	gtk_box_pack_start(GTK_BOX(msgview->vbox), menubar, FALSE, TRUE, 0);
-	gtk_box_reorder_child(GTK_BOX(msgview->vbox), menubar, 0);
+	gtk_box_pack_start(GTK_BOX(window_vbox), menubar, FALSE, TRUE, 0);
 
-	gtk_container_add(GTK_CONTAINER(window), GTK_WIDGET_PTR(msgview));
+	body_vbox = gtk_vbox_new(FALSE, BORDER_WIDTH);
+	gtk_container_set_border_width(GTK_CONTAINER(body_vbox), BORDER_WIDTH);
+	gtk_box_pack_start(GTK_BOX(window_vbox), body_vbox, TRUE, TRUE, 0);
+
+	gtk_box_pack_start(GTK_BOX(body_vbox), GTK_WIDGET_PTR(msgview),
+			   TRUE, TRUE, 0);
 	gtk_widget_grab_focus(msgview->textview->text);
+
+	statusbar = gtk_statusbar_new();
+	gtk_box_pack_end(GTK_BOX(body_vbox), statusbar, FALSE, FALSE, 0);
+	msgview->statusbar = statusbar;
+	msgview->statusbar_cid = gtk_statusbar_get_context_id
+		(GTK_STATUSBAR(statusbar), "Message View");
+
 	gtk_widget_show_all(window);
 
 	msgview->new_window = TRUE;
 	msgview->window = window;
+	msgview->window_vbox = window_vbox;
+	msgview->body_vbox = body_vbox;
 	msgview->visible = TRUE;
 
 	messageview_init(msgview);
@@ -377,7 +398,6 @@ void messageview_init(MessageView *messageview)
 {
 	headerview_init(messageview->headerview);
 	textview_init(messageview->textview);
-	imageview_init(messageview->imageview);
 	mimeview_init(messageview->mimeview);
 	/* messageview_set_font(messageview); */
 }
@@ -455,6 +475,7 @@ static void messageview_change_view_type(MessageView *messageview,
 		gtkut_container_remove
 			(GTK_CONTAINER(GTK_WIDGET_PTR(messageview)),
 			 GTK_WIDGET_PTR(mimeview));
+		mimeview_clear(mimeview);
 
 		if (mimeview->vbox == GTK_WIDGET_PTR(textview)->parent)
 			gtkut_container_remove(GTK_CONTAINER(mimeview->vbox),
@@ -475,20 +496,19 @@ void messageview_clear(MessageView *messageview)
 	messageview_change_view_type(messageview, MVIEW_TEXT);
 	headerview_clear(messageview->headerview);
 	textview_clear(messageview->textview);
-	imageview_clear(messageview->imageview);
+	mimeview_clear(messageview->mimeview);
 }
 
 void messageview_destroy(MessageView *messageview)
 {
 	GtkWidget *textview  = GTK_WIDGET_PTR(messageview->textview);
-	GtkWidget *imageview = GTK_WIDGET_PTR(messageview->imageview);
+	GtkWidget *imageview = GTK_WIDGET_PTR(messageview->mimeview->imageview);
 	GtkWidget *mimeview  = GTK_WIDGET_PTR(messageview->mimeview);
 
 	messageview_list = g_list_remove(messageview_list, messageview);
 
 	headerview_destroy(messageview->headerview);
 	textview_destroy(messageview->textview);
-	imageview_destroy(messageview->imageview);
 	mimeview_destroy(messageview->mimeview);
 
 	procmsg_msginfo_free(messageview->msginfo);
@@ -597,7 +617,21 @@ void messageview_save_as(MessageView *messageview)
 		Xstrdup_a(filename, msginfo->subject, return);
 		subst_for_filename(filename);
 	}
-	dest = filesel_select_file(_("Save as"), filename);
+	if (g_getenv ("G_BROKEN_FILENAMES") &&
+	    filename && g_utf8_validate(filename, -1, NULL)) {
+		gchar *oldstr = filename;
+		filename = conv_codeset_strdup(filename,
+					       CS_UTF_8,
+					       conv_get_current_charset_str());
+		if (!filename) {
+			g_warning("summary_save_as(): faild to convert character set.");
+			filename = g_strdup(oldstr);
+		}
+		dest = filesel_select_file(_("Save as"), filename);
+		g_free(filename);
+	} else
+		dest = filesel_select_file(_("Save as"), filename);
+	filename = NULL;
 	if (!dest) return;
 	if (is_file_exist(dest)) {
 		AlertValue aval;
@@ -842,7 +876,7 @@ static void create_filter_cb(gpointer data, guint action, GtkWidget *widget)
 
 	procmsg_get_filter_keyword(messageview->msginfo, &header, &key,
 				   (PrefsFilterType)action);
-	prefs_filter_open(messageview->msginfo, header, key);
+	prefs_filter_open(messageview->msginfo, header);
 
 	g_free(header);
 	g_free(key);
