@@ -1,6 +1,6 @@
 /*
  * Sylpheed -- a GTK+ based, lightweight, and fast e-mail client
- * Copyright (C) 1999-2003 Hiroyuki Yamamoto
+ * Copyright (C) 1999-2004 Hiroyuki Yamamoto
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -41,6 +41,7 @@
 #include "main.h"
 #include "mimeview.h"
 #include "textview.h"
+#include "imageview.h"
 #include "procmime.h"
 #include "summaryview.h"
 #include "menu.h"
@@ -73,7 +74,6 @@ static void mimeview_show_image_part		(MimeView	*mimeview,
 						 MimeInfo	*partinfo);
 static void mimeview_change_view_type		(MimeView	*mimeview,
 						 MimeViewType	 type);
-static void mimeview_clear			(MimeView	*mimeview);
 
 static void mimeview_selected		(GtkCTree	*ctree,
 					 GtkCTreeNode	*node,
@@ -219,6 +219,7 @@ MimeView *mimeview_create(void)
 void mimeview_init(MimeView *mimeview)
 {
 	textview_init(mimeview->textview);
+	imageview_init(mimeview->imageview);
 }
 
 /* 
@@ -331,8 +332,29 @@ void mimeview_show_message(MimeView *mimeview, MimeInfo *mimeinfo,
 	}
 }
 
+void mimeview_clear(MimeView *mimeview)
+{
+	GtkCList *clist = GTK_CLIST(mimeview->ctree);
+
+	procmime_mimeinfo_free_all(mimeview->mimeinfo);
+	mimeview->mimeinfo = NULL;
+
+	gtk_clist_clear(clist);
+	textview_clear(mimeview->textview);
+	imageview_clear(mimeview->imageview);
+
+	mimeview->opened = NULL;
+
+	g_free(mimeview->file);
+	mimeview->file = NULL;
+
+	/* gtk_notebook_set_page(GTK_NOTEBOOK(mimeview->notebook), 0); */
+}
+
 void mimeview_destroy(MimeView *mimeview)
 {
+	textview_destroy(mimeview->textview);
+	imageview_destroy(mimeview->imageview);
 	procmime_mimeinfo_free_all(mimeview->mimeinfo);
 	g_free(mimeview->file);
 	g_free(mimeview);
@@ -497,25 +519,6 @@ static void mimeview_change_view_type(MimeView *mimeview, MimeViewType type)
 	mimeview->type = type;
 }
 
-static void mimeview_clear(MimeView *mimeview)
-{
-	GtkCList *clist = GTK_CLIST(mimeview->ctree);
-
-	procmime_mimeinfo_free_all(mimeview->mimeinfo);
-	mimeview->mimeinfo = NULL;
-
-	gtk_clist_clear(clist);
-	textview_clear(mimeview->textview);
-	imageview_clear(mimeview->imageview);
-
-	mimeview->opened = NULL;
-
-	g_free(mimeview->file);
-	mimeview->file = NULL;
-
-	/* gtk_notebook_set_page(GTK_NOTEBOOK(mimeview->notebook), 0); */
-}
-
 static void mimeview_selected(GtkCTree *ctree, GtkCTreeNode *node, gint column,
 			      MimeView *mimeview)
 {
@@ -754,7 +757,7 @@ static void mimeview_drag_data_get(GtkWidget	    *widget,
 		alertpanel_error
 			(_("Can't save the part of multipart message."));
 
-	uriname = g_strconcat("file:/", filename, NULL);
+	uriname = g_strconcat("file://", filename, NULL);
 	gtk_selection_data_set(selection_data, selection_data->target, 8,
 			       uriname, strlen(uriname));
 
@@ -785,14 +788,29 @@ static void mimeview_save_as(MimeView *mimeview)
 	partinfo = mimeview_get_selected_part(mimeview);
 	g_return_if_fail(partinfo != NULL);
 
-	if (partinfo->filename)
+	if (partinfo->filename) {
+		g_print("%s\n", partinfo->filename);
 		defname = partinfo->filename;
-	else if (partinfo->name) {
+	} else if (partinfo->name) {
 		Xstrdup_a(defname, partinfo->name, return);
 		subst_for_filename(defname);
 	}
 
-	filename = filesel_select_file(_("Save as"), defname);
+	if (g_getenv ("G_BROKEN_FILENAMES") &&
+	    defname && g_utf8_validate(defname, -1, NULL)) {
+		gchar *oldstr = defname;
+		defname = conv_codeset_strdup(defname,
+					      CS_UTF_8,
+					      conv_get_current_charset_str());
+		if (!defname) {
+			g_warning("summary_save_as(): faild to convert character set.");
+			defname = g_strdup(oldstr);
+		}
+		filename = filesel_select_file(_("Save as"), defname);
+		g_free(defname);
+	} else
+		filename = filesel_select_file(_("Save as"), defname);
+	defname = NULL;
 	if (!filename) return;
 	if (is_file_exist(filename)) {
 		AlertValue aval;
