@@ -1,6 +1,6 @@
 /*
  * Sylpheed -- a GTK+ based, lightweight, and fast e-mail client
- * Copyright (C) 1999-2003 Hiroyuki Yamamoto
+ * Copyright (C) 1999-2004 Hiroyuki Yamamoto
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -35,7 +35,6 @@
 #include "md5.h"
 #include "prefs_account.h"
 #include "utils.h"
-#include "inc.h"
 #include "recv.h"
 
 static gint pop3_greeting_recv		(Pop3Session *session,
@@ -248,10 +247,11 @@ static gint pop3_getrange_uidl_recv(Pop3Session *session, const gchar *data,
 		p = newline + 1;
 		if (p < lastp && *p == '\n') p++;
 
-		if (sscanf(buf, "%d %" Xstr(IDLEN) "s", &num, id) != 2)
-			return -1;
-		if (num <= 0 || num > session->count)
-			return -1;
+		if (sscanf(buf, "%d %" Xstr(IDLEN) "s", &num, id) != 2 ||
+		    num <= 0 || num > session->count) {
+			log_warning(_("invalid UIDL response: %s\n"), buf);
+			continue;
+		}
 
 		session->msg[num].uidl = g_strdup(id);
 
@@ -333,8 +333,8 @@ static gint pop3_retr_recv(Pop3Session *session, const gchar *data, guint len)
 		return -1;
 	}
 
-	/* drop_ok: 0: success 1: don't receive -1: error */
-	drop_ok = inc_drop_message(file, session);
+	drop_ok = session->drop_message(session, file);
+	unlink(file);
 	g_free(file);
 	if (drop_ok < 0) {
 		session->error_val = PS_IOERR;
@@ -347,7 +347,9 @@ static gint pop3_retr_recv(Pop3Session *session, const gchar *data, guint len)
 
 	session->msg[session->cur_msg].received = TRUE;
 	session->msg[session->cur_msg].recv_time =
-		drop_ok == 1 ? RECV_TIME_KEEP : session->current_time;
+		drop_ok == DROP_DONT_RECEIVE ? RECV_TIME_KEEP
+			: drop_ok == DROP_DELETE ? RECV_TIME_DELETE
+			: session->current_time;
 
 	return PS_SUCCESS;
 }
@@ -609,11 +611,12 @@ static Pop3State pop3_lookup_next(Pop3Session *session)
 		     ac->size_limit > 0 &&
 		     size > ac->size_limit * 1024);
 
-		if (ac->rmmail &&
-		    msg->recv_time != RECV_TIME_NONE &&
-		    msg->recv_time != RECV_TIME_KEEP &&
-		    session->current_time - msg->recv_time >=
-		    ac->msg_leave_time * 24 * 60 * 60) {
+		if (msg->recv_time == RECV_TIME_DELETE ||
+		    (ac->rmmail &&
+		     msg->recv_time != RECV_TIME_NONE &&
+		     msg->recv_time != RECV_TIME_KEEP &&
+		     session->current_time - msg->recv_time >=
+		     ac->msg_leave_time * 24 * 60 * 60)) {
 			log_print(_("POP3: Deleting expired message %d\n"),
 				  session->cur_msg);
 			pop3_delete_send(session);
@@ -834,10 +837,12 @@ static gint pop3_session_recv_data_finished(Session *session, guchar *data,
 		if (pop3_retr_recv(pop3_session, data, len) < 0)
 			return -1;
 
-		if (pop3_session->ac_prefs->rmmail &&
-		    pop3_session->ac_prefs->msg_leave_time == 0 &&
-		    pop3_session->msg[pop3_session->cur_msg].recv_time
-		    != RECV_TIME_KEEP)
+		if (pop3_session->msg[pop3_session->cur_msg].recv_time
+		    == RECV_TIME_DELETE ||
+		    (pop3_session->ac_prefs->rmmail &&
+		     pop3_session->ac_prefs->msg_leave_time == 0 &&
+		     pop3_session->msg[pop3_session->cur_msg].recv_time
+		     != RECV_TIME_KEEP))
 			pop3_delete_send(pop3_session);
 		else if (pop3_session->cur_msg == pop3_session->count)
 			pop3_logout_send(pop3_session);
