@@ -109,17 +109,18 @@ void prefs_config_parse_one_line(PrefParam *param, const gchar *buf)
 		case P_STRING:
 		{
 #warning FIXME_GTK2
-			gchar *tmp;
+			gchar *tmp = NULL;
 
-			tmp = *value ?
-				conv_codeset_strdup(value,
-						    conv_get_current_charset_str(),
-						    CS_UTF_8)
-				: g_strdup("");
-			if (!tmp) {
-				g_warning("faild to convert character set.");
-				tmp = g_strdup(value);
+			if (*value) {
+				tmp = conv_codeset_strdup(value,
+							  conv_get_current_charset_str(),
+							  CS_UTF_8);
+				if (!tmp) {
+					g_warning("failed to convert character set.");
+					tmp = g_strdup(value);
+				}
 			}
+			
 			g_free(*((gchar **)param[i].data));
 			*((gchar **)param[i].data) = tmp;
 			break;
@@ -158,8 +159,8 @@ if (!(func)) \
 	return; \
 } \
 
-void prefs_save_config(PrefParam *param, const gchar *label,
-		       const gchar *rcfile)
+void prefs_write_config(PrefParam *param, const gchar *label,
+			const gchar *rcfile)
 {
 	FILE *orig_fp;
 	PrefFile *pfile;
@@ -393,17 +394,18 @@ void prefs_set_default(PrefParam *param)
 			if (param[i].defval != NULL) {
 				if (!strncasecmp(param[i].defval, "ENV_", 4)) {
 					const gchar *envstr;
-					gchar *tmp;
+					gchar *tmp = NULL;
 
 					envstr = g_getenv(param[i].defval + 4);
-					tmp = envstr && *envstr ?
-						conv_codeset_strdup(envstr,
-								    conv_get_current_charset_str(),
-								    CS_UTF_8)
-						: g_strdup("");
-					if (!tmp) {
-						g_warning("faild to convert character set.");
-						tmp = g_strdup(envstr);
+					if (envstr) {
+						tmp = conv_codeset_strdup(
+							envstr,
+							conv_get_current_charset_str(),
+							CS_UTF_8);
+						if (!tmp) {
+							g_warning("failed to convert character set.");
+							tmp = g_strdup(envstr);
+						}
 					}
 					*((gchar **)param[i].data) = tmp;
 				} else if (param[i].defval[0] == '~')
