@@ -1,6 +1,6 @@
 /*
  * Sylpheed -- a GTK+ based, lightweight, and fast e-mail client
- * Copyright (C) 1999-2003 Hiroyuki Yamamoto
+ * Copyright (C) 1999-2004 Hiroyuki Yamamoto
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -760,7 +760,7 @@ static gboolean sock_get_address_info_async_cb(GIOChannel *source,
 	SockLookupData *lookup_data = (SockLookupData *)data;
 	GList *addr_list = NULL;
 	SockAddrData *addr_data;
-	guint bytes_read;
+	gsize bytes_read;
 	gint ai_member[4];
 	struct sockaddr *addr;
 
@@ -996,6 +996,11 @@ gint ssl_read(SSL *ssl, gchar *buf, gint len)
 {
 	gint ret;
 
+	if (SSL_pending(ssl) == 0) {
+		if (fd_check_io(SSL_get_rfd(ssl), G_IO_IN) < 0)
+			return -1;
+	}
+
 	ret = SSL_read(ssl, buf, len);
 
 	switch (SSL_get_error(ssl, ret)) {
@@ -1234,6 +1239,11 @@ gint ssl_peek(SSL *ssl, gchar *buf, gint len)
 {
 	gint ret;
 
+	if (SSL_pending(ssl) == 0) {
+		if (fd_check_io(SSL_get_rfd(ssl), G_IO_IN) < 0)
+			return -1;
+	}
+
 	ret = SSL_peek(ssl, buf, len);
 
 	switch (SSL_get_error(ssl, ret)) {
